[![version](https://img.shields.io/pypi/v/sospcat.svg)](https://pypi.org/project/sospcat)
[![Documentation Status](https://readthedocs.org/projects/sospcatpy/badge/?version=main)](https://sospcatpy.readthedocs.io/en/main/?badge=main)
[![GitHub stars](https://img.shields.io/github/stars/j-i-l/sospcatpy.svg?style=flat-square&logo=github&label=Stars&logoColor=white)](https://github.com/j-i-l/SoSpCATpy)
[![PyPi downloads](https://img.shields.io/pypi/dm/sospcat.svg?style=flat-square)](https://pypistats.org/packages/sospcat)
[![Requirements Status](https://requires.io/github/j-i-l/SoSpCATpy/requirements.svg?branch=main)](https://requires.io/github/j-i-l/SoSpCATpy/requirements/?branch=main)
[![wheel](https://img.shields.io/pypi/wheel/sospcat.svg)](https://pypi.org/project/sospcat)

This package is a python implementation of the Social-spatial Community Assignment Test (SoSpCAT).

SoSpCAT is a method to quantify the spatial signal present in social group structures.

# Installation
The package can be installed from the Python Package Index:

```bash
pip install sospcat
```

or directly from git with:

```bash
pip install git+https://github.com/j-i-l/sospcatpy.git
```

